@@ -7,12 +7,12 @@ RDF::Trine::Parser::RDFa - RDFa Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::RDFa version 1.012
+This document describes RDF::Trine::Parser::RDFa version 1.015
 
 =head1 SYNOPSIS
 
  use RDF::Trine::Parser;
- my $parser	= RDF::Trine::Parser->new( 'rdfxml' );
+ my $parser	= RDF::Trine::Parser->new( 'rdfa' );
  $parser->parse_into_model( $base_uri, $data, $model );
 
 =head1 DESCRIPTION
@@ -50,7 +50,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION, $HAVE_RDFA_PARSER);
 BEGIN {
-	$VERSION	= '1.012';
+	$VERSION	= '1.015';
 	if (can_load( modules => { 'RDF::RDFa::Parser' => 0.30 })) {
 		$HAVE_RDFA_PARSER	= 1;
 		$RDF::Trine::Parser::parser_names{ 'rdfa' }	= __PACKAGE__;
