@@ -4,7 +4,7 @@ RDF::Trine::Store::DBI::SQLite - SQLite subclass of DBI store
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::DBI::SQLite version 1.013
+This document describes RDF::Trine::Store::DBI::SQLite version 1.015
 
 =head1 SYNOPSIS
 
@@ -18,7 +18,15 @@ This document describes RDF::Trine::Store::DBI::SQLite version 1.013
                                        });
 
 
-=head1 DESCRIPTION
+=head1 CHANGES IN VERSION 1.015
+
+The schema used to encode RDF data in SQLite changed in RDF::Trine version
+1.015 to fix a bug that was causing data loss. This change is not backwards
+compatible, and is not compatible with the shared schema used by the other
+database backends supported by RDF::Trine (PostgreSQL and MySQL).
+
+To exchange data between SQLite and other databases, the data will require
+export to an RDF serialization and re-import to the new database.
 
 =cut
 
@@ -31,10 +39,13 @@ use base qw(RDF::Trine::Store::DBI);
 
 
 use Scalar::Util qw(blessed reftype refaddr);
+use Encode;
+use Digest::MD5 ('md5');
+use Math::BigInt;
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "1.013";
+	$VERSION	= "1.015";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
@@ -81,6 +92,30 @@ sub new_with_config {
 	return $self;
 }
 
+# SQLite only supports 64-bit SIGNED integers, so this hash function masks out
+# the high-bit on hash values (unlike the superclass which produces full 64-bit
+# integers)
+sub _mysql_hash {
+	if (ref($_[0])) {
+		my $self = shift;
+	}
+	Carp::confess unless scalar(@_);
+	my $data	= encode('utf8', shift);
+	my @data	= unpack('C*', md5( $data ));
+	my $sum		= Math::BigInt->new('0');
+	# CHANGE: 7 -> 6, Smaller numbers for Sqlite which does not support real 64-bit :(
+	foreach my $count (0 .. 7) {
+		my $data	= Math::BigInt->new( $data[ $count ] ); #shift(@data);
+		my $part	= $data << (8 * $count);
+#		warn "+ $part\n";
+		$sum		+= $part;
+	}
+#	warn "= $sum\n";
+	$sum    = $sum->band(Math::BigInt->new('0x7fff_ffff_ffff_ffff'));
+	$sum	=~ s/\D//;	# get rid of the extraneous '+' that pops up under perl 5.6
+	return $sum;
+}
+
 =item C<< init >>
 
 Creates the necessary tables in the underlying database.
@@ -92,11 +127,11 @@ sub init {
 	my $dbh		= $self->dbh;
 	my $name	= $self->model_name;
 	$self->SUPER::init();
-	my $id		= RDF::Trine::Store::DBI::_mysql_hash( $name );
+	my $id		= $self->_mysql_hash( $name );
 	
 	my $table	= "Statements${id}";
+	local($dbh->{AutoCommit})	= 0;
 	unless ($self->_table_exists($table)) {
-		$dbh->begin_work;
 		$dbh->do( "CREATE INDEX idx_${name}_spog ON Statements${id} (Subject,Predicate,Object,Context);" ) || do { $dbh->rollback; return };
 		$dbh->do( "CREATE INDEX idx_${name}_pogs ON Statements${id} (Predicate,Object,Context,Subject);" ) || do { $dbh->rollback; return };
 		$dbh->do( "CREATE INDEX idx_${name}_opcs ON Statements${id} (Object,Predicate,Context,Subject);" ) || do { $dbh->rollback; return };
